@@ -5,7 +5,7 @@ import fies
 import json
 import hashlib
 import rename_lock
-from sout import sout
+from sout import sout, souts
 
 # DBディレクトリが存在しないときに作成
 def make_db_dir(db_dir):
@@ -144,8 +144,7 @@ class Table:
 		rlock.unlock()
 	# 文字列化
 	def __str__(self):
-		return "<json_stock Table '%s' (%d records)>"%(
-			self.table_name, len(self))
+		return souts(self)	# soutがjson-stockの可視化に公式に対応している
 	# 文字列化_その2
 	def __repr__(self):
 		return str(self)
@@ -216,7 +215,7 @@ class JsonStock:
 			yield table_name
 	# 文字列化
 	def __str__(self):
-		return "<json_stock DB (%d tables)>"%len(self)
+		return souts(self)	# soutがjson-stockの可視化に公式に対応している
 	# 文字列化_その2
 	def __repr__(self):
 		return str(self)
