@@ -30,6 +30,8 @@ with test_table.lock("test") as rec:	# lock the "test" key
 	rec.value["hello"] += "!!"
 # read value
 print(test_table["test"])
+# show table
+print(test_table)
 # transaction example 2 (without with)
 rec = test_table.lock("test")
 rec.value = "hoge"
